/* A Bison parser, made by GNU Bison 1.875.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Written by Richard Stallman by simplifying the original so called
   ``semantic'' parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Using locations.  */
#define YYLSP_NEEDED 0

/* If NAME_PREFIX is specified substitute the variables and functions
   names.  */
#define yyparse ipparse
#define yylex   iplex
#define yyerror iperror
#define yylval  iplval
#define yychar  ipchar
#define yydebug ipdebug
#define yynerrs ipnerrs


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     SET = 258,
     D_ACTIVATE = 259,
     D_LOAD = 260,
     D_BACKGROUND = 261,
     D_CALIBRATE = 262,
     D_RANGE = 263,
     D_DEVIATION = 264,
     D_INFO = 265,
     D_EXPORT = 266,
     F_RUN = 267,
     F_CONTINUE = 268,
     F_METHOD = 269,
     F_INFO = 270,
     S_ADD = 271,
     S_FREEZE = 272,
     S_HISTORY = 273,
     S_INFO = 274,
     S_GUESS = 275,
     S_REMOVE = 276,
     S_CHANGE = 277,
     S_VALUE = 278,
     S_EXPORT = 279,
     C_WAVELENGTH = 280,
     C_ADD = 281,
     C_INFO = 282,
     C_REMOVE = 283,
     C_FIND = 284,
     O_PLOT = 285,
     O_LOG = 286,
     O_INCLUDE = 287,
     O_WAIT = 288,
     O_DUMP = 289,
     M_FINDPEAK = 290,
     QUIT = 291,
     PLUS_MINUS = 292,
     TWO_COLONS = 293,
     SEP = 294,
     FILENAME = 295,
     DASH_STRING = 296,
     EQ_STRING = 297,
     LOWERCASE = 298,
     G_TYPE = 299,
     F_TYPE = 300,
     Z_TYPE = 301,
     PH_TYPE = 302,
     UINt = 303,
     UI_DASH = 304,
     UI_SLASH = 305,
     INt = 306,
     A_NUM = 307,
     G_NUM = 308,
     F_NUM = 309,
     Z_NUM = 310,
     PH_NUM = 311,
     FLOAt = 312,
     P_NUM = 313,
     NEW_A = 314,
     LEX_ERROR = 315
   };
#endif
#define SET 258
#define D_ACTIVATE 259
#define D_LOAD 260
#define D_BACKGROUND 261
#define D_CALIBRATE 262
#define D_RANGE 263
#define D_DEVIATION 264
#define D_INFO 265
#define D_EXPORT 266
#define F_RUN 267
#define F_CONTINUE 268
#define F_METHOD 269
#define F_INFO 270
#define S_ADD 271
#define S_FREEZE 272
#define S_HISTORY 273
#define S_INFO 274
#define S_GUESS 275
#define S_REMOVE 276
#define S_CHANGE 277
#define S_VALUE 278
#define S_EXPORT 279
#define C_WAVELENGTH 280
#define C_ADD 281
#define C_INFO 282
#define C_REMOVE 283
#define C_FIND 284
#define O_PLOT 285
#define O_LOG 286
#define O_INCLUDE 287
#define O_WAIT 288
#define O_DUMP 289
#define M_FINDPEAK 290
#define QUIT 291
#define PLUS_MINUS 292
#define TWO_COLONS 293
#define SEP 294
#define FILENAME 295
#define DASH_STRING 296
#define EQ_STRING 297
#define LOWERCASE 298
#define G_TYPE 299
#define F_TYPE 300
#define Z_TYPE 301
#define PH_TYPE 302
#define UINt 303
#define UI_DASH 304
#define UI_SLASH 305
#define INt 306
#define A_NUM 307
#define G_NUM 308
#define F_NUM 309
#define Z_NUM 310
#define PH_NUM 311
#define FLOAt 312
#define P_NUM 313
#define NEW_A 314
#define LEX_ERROR 315




/* Copy the first part of user declarations.  */
#line 5 "./parser.yy"

#include "common.h"
RCSID("$Id: parser.yy,v 1.12 2005/02/16 21:04:26 wojdyr Exp $")
#include <string>
#include <stdlib.h>
#include <vector>
#include "v_fit.h"
#include "crystal.h"
#include "sum.h"
#include "data.h"
#include "ui.h"
#include "manipul.h"
#include "other.h"
#include "pcore.h"

using namespace std;
int iperror (char *s);
int iplex ();
struct yy_buffer_state;
yy_buffer_state *yy_scan_string(const char *str);
void ip_delete_buffer (yy_buffer_state *b);
vector<int> ivec, ivec2;
vector <double> fvec;
vector<Pag> pgvec;

bool new_line = false;

void replot()
{
    if (new_line)
        new_line = false;
    else
        return; //do not replot
    if (/*auto_plot >= 2 &&*/ AL->was_changed()) {
        getUI()->drawPlot(2);
	AL->was_plotted();
    }
}

#define YYERROR_VERBOSE 1



/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 50 "./parser.yy"
typedef union YYSTYPE {
    bool bol;
    int i;
    char c;
    double f;
    Pre_string s;
    pre_Hkl pl;
    struct { int ph; pre_Hkl hkl; } ph_n_pl;
    pre_Domain pre_domain;
    struct { double l, r; } range;
    Pre_Pag pre_pag;
    struct { One_of_fzg fzg; char c; } fzg_type_type;
    struct { One_of_fzg fzg; int i; } fzg_num_type;
} YYSTYPE;
/* Line 191 of yacc.c.  */
#line 262 "parser.tab.cc"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif



/* Copy the second part of user declarations.  */


/* Line 214 of yacc.c.  */
#line 274 "parser.tab.cc"

#if ! defined (yyoverflow) || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# if YYSTACK_USE_ALLOCA
#  define YYSTACK_ALLOC alloca
# else
#  ifndef YYSTACK_USE_ALLOCA
#   if defined (alloca) || defined (_ALLOCA_H)
#    define YYSTACK_ALLOC alloca
#   else
#    ifdef __GNUC__
#     define YYSTACK_ALLOC __builtin_alloca
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's `empty if-body' warning. */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
# else
#  if defined (__STDC__) || defined (__cplusplus)
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   define YYSIZE_T size_t
#  endif
#  define YYSTACK_ALLOC malloc
#  define YYSTACK_FREE free
# endif
#endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */


#if (! defined (yyoverflow) \
     && (! defined (__cplusplus) \
	 || (YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  short yyss;
  YYSTYPE yyvs;
  };

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
      + YYSTACK_GAP_MAXIMUM)

/* Copy COUNT objects from FROM to TO.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if 1 < __GNUC__
#   define YYCOPY(To, From, Count) \
      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
#  else
#   define YYCOPY(To, From, Count)		\
      do					\
	{					\
	  register YYSIZE_T yyi;		\
	  for (yyi = 0; yyi < (Count); yyi++)	\
	    (To)[yyi] = (From)[yyi];		\
	}					\
      while (0)
#  endif
# endif

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack)					\
    do									\
      {									\
	YYSIZE_T yynewbytes;						\
	YYCOPY (&yyptr->Stack, Stack, yysize);				\
	Stack = &yyptr->Stack;						\
	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
	yyptr += yynewbytes / sizeof (*yyptr);				\
      }									\
    while (0)

#endif

#if defined (__STDC__) || defined (__cplusplus)
   typedef signed char yysigned_char;
#else
   typedef short yysigned_char;
#endif

/* YYFINAL -- State number of the termination state. */
#define YYFINAL  2
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   483

/* YYNTOKENS -- Number of terminals. */
#define YYNTOKENS  76
/* YYNNTS -- Number of nonterminals. */
#define YYNNTS  34
/* YYNRULES -- Number of rules. */
#define YYNRULES  191
/* YYNRULES -- Number of states. */
#define YYNSTATES  379

/* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   315

#define YYTRANSLATE(YYX) 						\
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
static const unsigned char yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,    61,     2,     2,    67,    63,     2,     2,
      71,    72,    62,    73,     2,    74,    64,    75,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,    70,     2,
      69,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,    65,     2,    66,    68,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
      55,    56,    57,    58,    59,    60
};

#if YYDEBUG
/* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
   YYRHS.  */
static const unsigned short yyprhs[] =
{
       0,     0,     3,     4,     7,    10,    15,    21,    25,    30,
      34,    37,    43,    50,    55,    61,    67,    72,    76,    79,
      85,    92,   100,   108,   117,   122,   127,   130,   134,   138,
     143,   148,   151,   155,   159,   164,   167,   170,   176,   180,
     183,   187,   190,   193,   197,   200,   204,   209,   214,   218,
     224,   231,   236,   244,   247,   251,   256,   259,   263,   267,
     272,   276,   280,   284,   288,   292,   296,   300,   303,   307,
     311,   315,   320,   325,   331,   335,   339,   346,   351,   353,
     356,   360,   365,   370,   375,   379,   384,   388,   393,   397,
     399,   404,   410,   414,   418,   422,   425,   429,   433,   436,
     441,   445,   450,   454,   458,   462,   466,   469,   473,   477,
     482,   484,   486,   489,   492,   498,   503,   509,   516,   517,
     519,   521,   524,   527,   530,   534,   538,   544,   546,   548,
     551,   553,   557,   563,   565,   567,   569,   571,   573,   575,
     577,   579,   581,   583,   586,   588,   591,   593,   595,   596,
     598,   599,   601,   603,   606,   608,   610,   611,   613,   614,
     616,   617,   619,   620,   622,   623,   625,   627,   629,   633,
     637,   641,   642,   646,   652,   653,   656,   660,   663,   664,
     667,   671,   675,   676,   680,   683,   685,   687,   689,   692,
     694,   697
};

/* YYRHS -- A `-1'-separated list of the rules' RHS. */
static const yysigned_char yyrhs[] =
{
      77,     0,    -1,    -1,    77,    39,    -1,    77,    78,    -1,
      77,    60,     1,    39,    -1,    77,     1,    60,     1,    39,
      -1,    77,     1,    39,    -1,     3,    41,    42,    39,    -1,
       3,    41,    39,    -1,     3,    39,    -1,     4,    94,    38,
      94,    39,    -1,     4,    61,    94,    38,    94,    39,    -1,
       4,    62,    38,    39,    -1,     4,    94,    38,    62,    39,
      -1,     5,    98,   105,    40,    39,    -1,     8,   107,    84,
      39,    -1,     8,    84,    39,    -1,     8,    39,    -1,     8,
      62,    96,    96,    39,    -1,     6,    62,    48,    96,    96,
      39,    -1,     6,    62,    48,    96,    63,    96,    39,    -1,
       6,    62,    48,    96,    96,    63,    39,    -1,     6,    62,
      48,    96,    63,    96,    63,    39,    -1,     6,    96,    96,
      39,    -1,     6,    61,    96,    39,    -1,     6,    39,    -1,
       6,    64,    39,    -1,     6,    61,    39,    -1,     7,    96,
      96,    39,    -1,     7,    61,    96,    39,    -1,     7,    39,
      -1,     7,    64,    39,    -1,     7,    61,    39,    -1,     9,
      43,    97,    39,    -1,     9,    39,    -1,    10,    39,    -1,
      11,    98,    40,   100,    39,    -1,    12,    48,    39,    -1,
      12,    39,    -1,    13,    48,    39,    -1,    13,    39,    -1,
      14,    39,    -1,    14,    43,    39,    -1,    15,    39,    -1,
      15,    62,    39,    -1,    15,    62,    62,    39,    -1,    16,
      88,    90,    39,    -1,    16,    79,    39,    -1,    22,    79,
      96,    81,    39,    -1,    22,    79,    96,    81,    80,    39,
      -1,    22,    54,    45,    39,    -1,    22,    54,    65,    95,
      66,    90,    39,    -1,    17,    39,    -1,    17,    79,    39,
      -1,    17,    61,    79,    39,    -1,    18,    39,    -1,    18,
      51,    39,    -1,    18,    48,    39,    -1,    18,    62,    93,
      39,    -1,    18,   109,    39,    -1,    19,    79,    39,    -1,
      19,    89,    39,    -1,    19,    67,    39,    -1,    19,    68,
      39,    -1,    19,    69,    39,    -1,    19,    88,    39,    -1,
      19,    39,    -1,    20,    54,    39,    -1,    21,    79,    39,
      -1,    21,    89,    39,    -1,    21,    62,    62,    39,    -1,
      23,    96,    99,    39,    -1,    23,    89,    96,    99,    39,
      -1,    23,    53,    39,    -1,    23,    79,    39,    -1,    24,
     101,    98,    40,   100,    39,    -1,    35,    96,    97,    39,
      -1,    35,    -1,    30,    39,    -1,    30,    84,    39,    -1,
      30,    83,    83,    39,    -1,    30,    64,    84,    39,    -1,
      30,    84,    64,    39,    -1,    30,    64,    39,    -1,    30,
      64,    64,    39,    -1,    30,   107,    39,    -1,    31,    98,
      40,    39,    -1,    31,    61,    39,    -1,    31,    -1,    32,
      40,   106,    39,    -1,    32,    61,    40,   106,    39,    -1,
      32,    61,    39,    -1,    33,    96,    39,    -1,    34,    40,
      39,    -1,    36,    39,    -1,    25,    90,    39,    -1,    25,
      61,    39,    -1,    25,    39,    -1,    26,    47,    90,    39,
      -1,    26,    85,    39,    -1,    26,    85,    91,    39,    -1,
      27,    63,    39,    -1,    27,    47,    39,    -1,    27,    56,
      39,    -1,    27,    85,    39,    -1,    27,    39,    -1,    28,
      56,    39,    -1,    28,    85,    39,    -1,    29,    85,    97,
      39,    -1,    52,    -1,    59,    -1,    59,    80,    -1,    65,
      66,    -1,    65,    96,    70,    96,    66,    -1,    65,    37,
      96,    66,    -1,    65,    96,    37,    96,    66,    -1,    65,
      96,    37,    96,    63,    66,    -1,    -1,    63,    -1,    70,
      -1,    96,    70,    -1,    70,    96,    -1,    65,    66,    -1,
      65,    82,    66,    -1,    96,    70,    96,    -1,    65,    96,
      70,    96,    66,    -1,    82,    -1,    83,    -1,    56,    86,
      -1,    86,    -1,    71,    48,    72,    -1,    71,    92,    92,
      92,    72,    -1,    79,    -1,    53,    -1,    58,    -1,    45,
      -1,    46,    -1,    44,    -1,    54,    -1,    55,    -1,    53,
      -1,    87,    -1,    90,    87,    -1,    54,    -1,    91,    54,
      -1,    51,    -1,    48,    -1,    -1,    48,    -1,    -1,    48,
      -1,    48,    -1,    95,    48,    -1,    57,    -1,    92,    -1,
      -1,    96,    -1,    -1,    43,    -1,    -1,    62,    -1,    -1,
      73,    -1,    -1,    54,    -1,    56,    -1,    85,    -1,   101,
      73,    54,    -1,   101,    73,    56,    -1,   101,    73,    85,
      -1,    -1,    48,    70,    48,    -1,    48,    70,    48,    70,
      48,    -1,    -1,    49,    48,    -1,    49,    50,    48,    -1,
      50,    48,    -1,    -1,    62,    48,    -1,    73,    62,    48,
      -1,   102,   103,   104,    -1,    -1,   106,    49,    48,    -1,
     106,    48,    -1,    73,    -1,    74,    -1,    50,    -1,   109,
      50,    -1,   108,    -1,   108,    48,    -1,    75,    -1
};

/* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
static const unsigned short yyrline[] =
{
       0,    97,    97,    98,    99,   100,   103,   106,   110,   113,
     114,   115,   116,   117,   118,   119,   122,   123,   127,   129,
     130,   132,   134,   136,   138,   139,   140,   141,   142,   143,
     144,   145,   146,   147,   148,   149,   150,   151,   153,   154,
     155,   156,   157,   158,   159,   160,   161,   162,   163,   164,
     165,   167,   168,   170,   171,   172,   173,   174,   175,   176,
     177,   178,   179,   180,   181,   182,   183,   184,   185,   186,
     187,   188,   189,   190,   192,   193,   194,   196,   198,   199,
     200,   201,   203,   204,   205,   206,   207,   208,   209,   210,
     211,   212,   214,   215,   216,   217,   219,   220,   221,   222,
     223,   224,   226,   227,   228,   230,   231,   233,   234,   235,
     240,   241,   242,   245,   246,   248,   249,   251,   255,   256,
     259,   260,   261,   264,   265,   266,   267,   270,   271,   274,
     275,   278,   284,   287,   288,   289,   292,   293,   294,   297,
     298,   299,   302,   303,   306,   307,   310,   311,   314,   315,
     318,   319,   322,   323,   326,   327,   330,   331,   334,   335,
     338,   339,   341,   342,   345,   346,   347,   348,   349,   350,
     352,   357,   358,   359,   362,   363,   364,   365,   368,   369,
     370,   373,   376,   377,   378,   381,   382,   385,   386,   389,
     390,   391
};
#endif

#if YYDEBUG || YYERROR_VERBOSE
/* YYTNME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals. */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "SET", "D_ACTIVATE", "D_LOAD", 
  "D_BACKGROUND", "D_CALIBRATE", "D_RANGE", "D_DEVIATION", "D_INFO", 
  "D_EXPORT", "F_RUN", "F_CONTINUE", "F_METHOD", "F_INFO", "S_ADD", 
  "S_FREEZE", "S_HISTORY", "S_INFO", "S_GUESS", "S_REMOVE", "S_CHANGE", 
  "S_VALUE", "S_EXPORT", "C_WAVELENGTH", "C_ADD", "C_INFO", "C_REMOVE", 
  "C_FIND", "O_PLOT", "O_LOG", "O_INCLUDE", "O_WAIT", "O_DUMP", 
  "M_FINDPEAK", "QUIT", "PLUS_MINUS", "TWO_COLONS", "SEP", "FILENAME", 
  "DASH_STRING", "EQ_STRING", "LOWERCASE", "G_TYPE", "F_TYPE", "Z_TYPE", 
  "PH_TYPE", "UINt", "UI_DASH", "UI_SLASH", "INt", "A_NUM", "G_NUM", 
  "F_NUM", "Z_NUM", "PH_NUM", "FLOAt", "P_NUM", "NEW_A", "LEX_ERROR", 
  "'!'", "'*'", "'%'", "'.'", "'['", "']'", "'$'", "'^'", "'<'", "':'", 
  "'('", "')'", "'+'", "'-'", "'/'", "$accept", "input", "exp", "a_num", 
  "domain", "opt_proc", "sim_range", "bracket_range", "range", "p_plane", 
  "plane", "pag", "fzg_type", "fzg_num", "pags_vec", "f_num_vec", "inr", 
  "opt_uint", "opt_uint_1", "uints", "flt", "opt_flt", "opt_lcase", 
  "opt_asterix", "opt_plus", "peaks_to_sum", "columns", "rows_of", 
  "dl_merge", "dload_arg", "rows", "sign", "uint_slashes_", 
  "uint_slashes", 0
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
   token YYLEX-NUM.  */
static const unsigned short yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   286,   287,   288,   289,   290,   291,   292,   293,   294,
     295,   296,   297,   298,   299,   300,   301,   302,   303,   304,
     305,   306,   307,   308,   309,   310,   311,   312,   313,   314,
     315,    33,    42,    37,    46,    91,    93,    36,    94,    60,
      58,    40,    41,    43,    45,    47
};
# endif

/* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const unsigned char yyr1[] =
{
       0,    76,    77,    77,    77,    77,    77,    77,    78,    78,
      78,    78,    78,    78,    78,    78,    78,    78,    78,    78,
      78,    78,    78,    78,    78,    78,    78,    78,    78,    78,
      78,    78,    78,    78,    78,    78,    78,    78,    78,    78,
      78,    78,    78,    78,    78,    78,    78,    78,    78,    78,
      78,    78,    78,    78,    78,    78,    78,    78,    78,    78,
      78,    78,    78,    78,    78,    78,    78,    78,    78,    78,
      78,    78,    78,    78,    78,    78,    78,    78,    78,    78,
      78,    78,    78,    78,    78,    78,    78,    78,    78,    78,
      78,    78,    78,    78,    78,    78,    78,    78,    78,    78,
      78,    78,    78,    78,    78,    78,    78,    78,    78,    78,
      79,    79,    79,    80,    80,    80,    80,    80,    81,    81,
      82,    82,    82,    83,    83,    83,    83,    84,    84,    85,
      85,    86,    86,    87,    87,    87,    88,    88,    88,    89,
      89,    89,    90,    90,    91,    91,    92,    92,    93,    93,
      94,    94,    95,    95,    96,    96,    97,    97,    98,    98,
      99,    99,   100,   100,   101,   101,   101,   101,   101,   101,
     101,   102,   102,   102,   103,   103,   103,   103,   104,   104,
     104,   105,   106,   106,   106,   107,   107,   108,   108,   109,
     109,   109
};

/* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
static const unsigned char yyr2[] =
{
       0,     2,     0,     2,     2,     4,     5,     3,     4,     3,
       2,     5,     6,     4,     5,     5,     4,     3,     2,     5,
       6,     7,     7,     8,     4,     4,     2,     3,     3,     4,
       4,     2,     3,     3,     4,     2,     2,     5,     3,     2,
       3,     2,     2,     3,     2,     3,     4,     4,     3,     5,
       6,     4,     7,     2,     3,     4,     2,     3,     3,     4,
       3,     3,     3,     3,     3,     3,     3,     2,     3,     3,
       3,     4,     4,     5,     3,     3,     6,     4,     1,     2,
       3,     4,     4,     4,     3,     4,     3,     4,     3,     1,
       4,     5,     3,     3,     3,     2,     3,     3,     2,     4,
       3,     4,     3,     3,     3,     3,     2,     3,     3,     4,
       1,     1,     2,     2,     5,     4,     5,     6,     0,     1,
       1,     2,     2,     2,     3,     3,     5,     1,     1,     2,
       1,     3,     5,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     2,     1,     2,     1,     1,     0,     1,
       0,     1,     1,     2,     1,     1,     0,     1,     0,     1,
       0,     1,     0,     1,     0,     1,     1,     1,     3,     3,
       3,     0,     3,     5,     0,     2,     3,     2,     0,     2,
       3,     3,     0,     3,     2,     1,     1,     1,     2,     1,
       2,     1
};

/* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
   STATE-NUM when YYTABLE doesn't specify something else to do.  Zero
   means the default is an error.  */
static const unsigned char yydefact[] =
{
       2,     0,     1,     0,     0,   150,   158,     0,     0,     0,
       0,     0,   158,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,   164,     0,     0,     0,     0,
       0,     0,    89,     0,     0,     0,    78,     0,     3,     0,
       4,     7,     0,    10,     0,   151,   150,     0,     0,   159,
     171,    26,   147,   146,   154,     0,     0,     0,   155,     0,
      31,     0,     0,     0,    18,     0,     0,   120,   185,   186,
     127,   128,     0,     0,     0,    35,   156,    36,     0,    39,
       0,    41,     0,    42,     0,    44,     0,   138,   136,   137,
     110,   111,     0,     0,    53,     0,     0,    56,     0,   187,
       0,   148,   191,   189,     0,    67,   141,   139,   140,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,   141,     0,     0,   160,   165,   166,     0,   167,   130,
     158,    98,   134,   135,     0,   133,   142,     0,     0,     0,
       0,   106,     0,     0,     0,     0,     0,     0,   156,    79,
       0,   128,     0,     0,     0,     0,   182,     0,     0,     0,
     156,    95,     0,     0,     9,     0,     0,     0,   150,     0,
     174,     0,    28,     0,     0,    27,     0,    33,     0,    32,
       0,     0,   123,     0,     0,   122,    17,   121,     0,   157,
       0,   162,    38,    40,    43,    45,     0,     0,   112,    48,
       0,     0,    54,    58,    57,   149,     0,   190,    60,   188,
      63,    64,    65,    61,    66,    62,    68,     0,    69,    70,
       0,     0,   118,    74,    75,   160,   161,     0,   129,   147,
       0,     0,     0,    97,    96,   143,     0,   100,   144,     0,
     103,   104,   102,   105,   107,   108,     0,    84,     0,     0,
       0,     0,    80,     0,    86,    88,     0,     0,    92,   182,
      93,    94,     0,     5,     6,     8,   150,    13,     0,     0,
       0,     0,     0,   178,     0,    25,     0,    24,    30,    29,
       0,   124,   121,   125,    16,    34,   163,     0,    46,     0,
     113,     0,    47,    55,    59,    71,    51,   152,     0,   119,
       0,     0,    72,   131,     0,   168,   169,   170,   162,    99,
     101,   145,   109,    85,    82,    81,     0,    83,    87,    90,
     184,     0,     0,    77,     0,    14,    11,   172,   175,     0,
     177,     0,     0,   181,    15,     0,     0,    19,     0,    37,
       0,     0,     0,   153,     0,    49,     0,    73,     0,     0,
     183,    91,    12,     0,   176,   179,     0,     0,    20,     0,
     126,   115,     0,     0,     0,    50,   132,    76,   173,   180,
      21,     0,    22,     0,   116,   114,    52,    23,   117
};

/* YYDEFGOTO[NTERM-NUM]. */
static const short yydefgoto[] =
{
      -1,     1,    40,   135,   198,   300,    70,    71,    72,   128,
     129,   136,    93,   114,   137,   239,    58,   206,    48,   298,
      73,   190,    50,   227,   287,   130,   170,   273,   333,   171,
     257,    74,   103,   104
};

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
#define YYPACT_NINF -135
static const short yypact[] =
{
    -135,   336,  -135,    78,   227,   226,    35,   136,    72,    22,
     201,     6,    35,   -16,   199,   216,    -9,   219,   143,   -13,
     103,    56,   246,   263,   238,    83,   107,    30,    -6,   105,
     108,    24,    63,    82,   259,    75,   259,   134,  -135,   182,
    -135,  -135,   188,  -135,   241,  -135,   163,   172,   179,  -135,
     185,  -135,  -135,  -135,  -135,   195,   191,   221,  -135,   259,
    -135,   210,   237,   259,  -135,   259,   137,   259,  -135,  -135,
    -135,  -135,   257,   202,   148,  -135,   259,  -135,   262,  -135,
     267,  -135,   282,  -135,   290,  -135,    37,  -135,  -135,  -135,
    -135,   212,   291,   260,  -135,    93,   292,  -135,   293,  -135,
     294,   325,  -135,   326,    69,  -135,  -135,  -135,  -135,   299,
     337,   338,   339,   340,   341,   342,   320,   344,   345,    60,
     259,   346,   347,   259,   327,  -135,   316,   233,  -135,  -135,
       1,  -135,  -135,  -135,   349,  -135,  -135,   162,   260,   316,
     124,  -135,   351,   -20,   352,   353,    -3,   354,   259,  -135,
      70,   197,     3,   355,   356,   357,  -135,     0,   359,   360,
     259,  -135,   361,   362,  -135,   363,   365,   366,    66,   334,
     101,   367,  -135,   369,   259,  -135,   370,  -135,   371,  -135,
     372,   259,  -135,   348,   343,  -135,  -135,   259,   373,  -135,
     376,   333,  -135,  -135,  -135,  -135,   377,    34,  -135,  -135,
     173,   378,  -135,  -135,  -135,  -135,   379,  -135,  -135,  -135,
    -135,  -135,  -135,  -135,  -135,  -135,  -135,   380,  -135,  -135,
     381,   374,   358,  -135,  -135,   327,  -135,   384,  -135,   364,
     272,   152,   385,  -135,  -135,  -135,   183,  -135,  -135,   138,
    -135,  -135,  -135,  -135,  -135,  -135,   387,  -135,   388,   389,
     390,   368,  -135,   391,  -135,  -135,   392,   180,  -135,  -135,
    -135,  -135,   393,  -135,  -135,  -135,   163,  -135,   394,   395,
     396,   276,   397,   154,   398,  -135,   222,  -135,  -135,  -135,
     400,  -135,   259,  -135,  -135,  -135,  -135,   401,  -135,   259,
    -135,   -24,  -135,  -135,  -135,  -135,  -135,  -135,   -23,  -135,
      25,   402,  -135,  -135,   272,  -135,   316,  -135,   333,  -135,
    -135,  -135,  -135,  -135,  -135,  -135,   259,  -135,  -135,  -135,
    -135,   399,   255,  -135,   403,  -135,  -135,   382,  -135,   405,
    -135,   406,   386,  -135,  -135,   259,    41,  -135,   383,  -135,
     404,   259,   259,  -135,   260,  -135,   407,  -135,   408,   411,
    -135,  -135,  -135,   409,  -135,  -135,   410,    44,  -135,   412,
    -135,  -135,   248,   413,   198,  -135,  -135,  -135,  -135,  -135,
    -135,   416,  -135,   415,  -135,  -135,  -135,  -135,  -135
};

/* YYPGOTO[NTERM-NUM].  */
static const short yypgoto[] =
{
    -135,  -135,  -135,    -2,   135,  -135,   417,   -21,   -19,   -22,
    -115,  -134,   423,   303,   -91,  -135,  -118,  -135,   -42,  -135,
      -7,    21,     2,   231,   116,  -135,  -135,  -135,  -135,  -135,
     200,   429,  -135,  -135
};

/* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule which
   number is the opposite.  If zero, do what YYDEFACT says.
   If YYTABLE_NINF, syntax error.  */
#define YYTABLE_NINF -159
static const short yytable[] =
{
      59,    63,   200,   235,   166,   140,   145,   147,   148,   230,
     151,   228,   152,   341,    78,    92,    96,   124,   112,   241,
     117,   120,   122,    79,   228,   343,    97,   158,   228,   160,
      85,   228,    80,   141,   155,    98,   244,    99,   100,   258,
     259,   142,   252,   344,    49,    77,   342,   236,   173,   101,
     143,   127,   176,    86,   178,   188,   180,   144,   181,   184,
     185,    64,   102,   149,   345,   127,   235,   253,   127,   189,
      52,   289,    52,    53,   231,    53,   195,   138,    49,    54,
     358,    54,    52,   370,    65,    53,   139,    66,   150,    66,
     197,    54,    67,   201,    67,    68,    69,    68,    69,   196,
     290,   127,   235,  -158,   359,   220,    49,   371,   208,   247,
     115,    60,   304,   222,    45,   159,   225,    41,    52,   209,
      52,    53,   156,    53,   154,   221,   269,    54,   268,    54,
     250,   249,   232,    61,   248,    66,    62,   125,    42,   126,
      67,   189,   105,   157,   251,    90,   131,    87,    88,    89,
     271,   272,    91,   189,   127,    90,   106,   107,   108,    90,
     132,   146,    91,   237,   139,   133,    91,   276,   134,   246,
     109,   110,   111,   161,   280,    51,   127,   310,   238,   127,
     283,   262,    94,   162,    52,    52,   348,    53,    53,   163,
     291,   228,   311,    54,    54,    90,    52,    55,    56,    53,
      57,   234,    91,   182,    95,    54,   305,    67,   306,   307,
     167,    45,   292,    66,    90,   132,   331,   168,    67,   319,
     133,    91,   309,   127,   324,    90,   132,   332,   320,   321,
     235,   133,    91,   169,   172,    90,   132,   376,    81,   174,
      75,   133,    91,    52,    76,    52,    53,    82,    53,   177,
      90,   132,    54,   364,    54,    83,   133,    91,    52,    84,
     175,    53,    66,    87,    88,    89,    43,    54,    44,   336,
      52,    90,   187,    53,    45,   338,   179,   197,    91,    54,
     164,   229,   340,   165,    53,   335,    52,    46,    47,    53,
      90,   121,   107,   108,   351,    54,   186,    91,    90,   106,
     107,   108,   191,   320,   321,    91,   192,    52,   116,   283,
      53,   373,    90,   132,   374,    90,    54,   119,   133,    91,
      52,   193,    91,    53,   328,   118,   329,   123,   357,   194,
     199,   202,   203,   204,   362,   363,     2,     3,   210,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,   205,   207,    38,   211,   212,   213,   214,
     215,   216,   217,   218,   219,   223,   224,   127,   233,   226,
     240,   242,   243,   245,   254,   255,    39,   256,   260,   261,
     263,   264,   265,   266,   270,   267,   286,   274,   275,   277,
     278,   279,   284,   282,   281,   285,   288,   293,   294,   295,
     296,   299,   297,   302,   349,   308,   312,   313,   314,   315,
     317,   318,   323,   325,   326,   346,   303,   334,   316,   337,
     339,   347,   352,   113,   327,   330,   365,   350,   356,   360,
     367,   372,   353,   354,   355,   377,   301,   368,   369,   322,
     153,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     361,     0,     0,     0,     0,     0,     0,     0,     0,   375,
     366,   378,     0,   183
};

static const short yycheck[] =
{
       7,     8,    93,   137,    46,    27,    28,    29,    30,   127,
      31,   126,    31,    37,    12,    17,    18,    24,    20,    39,
      22,    23,    24,    39,   139,    48,    39,    34,   143,    36,
      39,   146,    48,    39,    32,    48,    39,    50,    51,    39,
      40,    47,    39,    66,    43,    39,    70,   138,    55,    62,
      56,    71,    59,    62,    61,    74,    63,    63,    65,    66,
      67,    39,    75,    39,    39,    71,   200,    64,    71,    76,
      48,    37,    48,    51,    73,    51,    39,    47,    43,    57,
      39,    57,    48,    39,    62,    51,    56,    65,    64,    65,
      65,    57,    70,    95,    70,    73,    74,    73,    74,    62,
      66,    71,   236,    40,    63,    45,    43,    63,    39,    39,
      54,    39,   230,   120,    48,    40,   123,    39,    48,    50,
      48,    51,    40,    51,    61,    65,   168,    57,    62,    57,
     151,   150,   130,    61,    64,    65,    64,    54,    60,    56,
      70,   148,    39,    61,   151,    52,    39,    44,    45,    46,
      49,    50,    59,   160,    71,    52,    53,    54,    55,    52,
      53,    56,    59,    39,    56,    58,    59,   174,    61,   148,
      67,    68,    69,    39,   181,    39,    71,    39,    54,    71,
     187,   160,    39,     1,    48,    48,   304,    51,    51,     1,
     197,   306,    54,    57,    57,    52,    48,    61,    62,    51,
      64,    39,    59,    66,    61,    57,    54,    70,    56,   231,
      38,    48,    39,    65,    52,    53,    62,    38,    70,    39,
      58,    59,    39,    71,   266,    52,    53,    73,    48,    49,
     364,    58,    59,    48,    39,    52,    53,    39,    39,    48,
      39,    58,    59,    48,    43,    48,    51,    48,    51,    39,
      52,    53,    57,   344,    57,    39,    58,    59,    48,    43,
      39,    51,    65,    44,    45,    46,    39,    57,    41,   276,
      48,    52,    70,    51,    48,   282,    39,    65,    59,    57,
      39,    48,   289,    42,    51,    63,    48,    61,    62,    51,
      52,    53,    54,    55,    39,    57,    39,    59,    52,    53,
      54,    55,    40,    48,    49,    59,    39,    48,    62,   316,
      51,    63,    52,    53,    66,    52,    57,    54,    58,    59,
      48,    39,    59,    51,    48,    22,    50,    24,   335,    39,
      39,    39,    39,    39,   341,   342,     0,     1,    39,     3,
       4,     5,     6,     7,     8,     9,    10,    11,    12,    13,
      14,    15,    16,    17,    18,    19,    20,    21,    22,    23,
      24,    25,    26,    27,    28,    29,    30,    31,    32,    33,
      34,    35,    36,    48,    48,    39,    39,    39,    39,    39,
      39,    39,    62,    39,    39,    39,    39,    71,    39,    62,
      39,    39,    39,    39,    39,    39,    60,    40,    39,    39,
      39,    39,    39,    38,    70,    39,    73,    40,    39,    39,
      39,    39,    39,    70,    66,    39,    39,    39,    39,    39,
      39,    63,    48,    39,   308,    40,    39,    39,    39,    39,
      39,    39,    39,    39,    39,   300,    72,    39,    70,    39,
      39,    39,    39,    20,    48,    48,    39,    48,    62,    66,
      39,    39,    70,    48,    48,    39,   225,    48,    48,   259,
      31,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      66,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    66,
      72,    66,    -1,    66
};

/* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
   symbol of state STATE-NUM.  */
static const unsigned char yystos[] =
{
       0,    77,     0,     1,     3,     4,     5,     6,     7,     8,
       9,    10,    11,    12,    13,    14,    15,    16,    17,    18,
      19,    20,    21,    22,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    33,    34,    35,    36,    39,    60,
      78,    39,    60,    39,    41,    48,    61,    62,    94,    43,
      98,    39,    48,    51,    57,    61,    62,    64,    92,    96,
      39,    61,    64,    96,    39,    62,    65,    70,    73,    74,
      82,    83,    84,    96,   107,    39,    43,    39,    98,    39,
      48,    39,    48,    39,    43,    39,    62,    44,    45,    46,
      52,    59,    79,    88,    39,    61,    79,    39,    48,    50,
      51,    62,    75,   108,   109,    39,    53,    54,    55,    67,
      68,    69,    79,    88,    89,    54,    62,    79,    89,    54,
      79,    53,    79,    89,    96,    54,    56,    71,    85,    86,
     101,    39,    53,    58,    61,    79,    87,    90,    47,    56,
      85,    39,    47,    56,    63,    85,    56,    85,    85,    39,
      64,    83,    84,   107,    61,    98,    40,    61,    96,    40,
      96,    39,     1,     1,    39,    42,    94,    38,    38,    48,
     102,   105,    39,    96,    48,    39,    96,    39,    96,    39,
      96,    96,    66,    82,    96,    96,    39,    70,    84,    96,
      97,    40,    39,    39,    39,    39,    62,    65,    80,    39,
      90,    79,    39,    39,    39,    48,    93,    48,    39,    50,
      39,    39,    39,    39,    39,    39,    39,    62,    39,    39,
      45,    65,    96,    39,    39,    96,    62,    99,    86,    48,
      92,    73,    98,    39,    39,    87,    90,    39,    54,    91,
      39,    39,    39,    39,    39,    39,    97,    39,    64,    84,
      83,    96,    39,    64,    39,    39,    40,   106,    39,    40,
      39,    39,    97,    39,    39,    39,    38,    39,    62,    94,
      70,    49,    50,   103,    40,    39,    96,    39,    39,    39,
      96,    66,    70,    96,    39,    39,    73,   100,    39,    37,
      66,    96,    39,    39,    39,    39,    39,    48,    95,    63,
      81,    99,    39,    72,    92,    54,    56,    85,    40,    39,
      39,    54,    39,    39,    39,    39,    70,    39,    39,    39,
      48,    49,   106,    39,    94,    39,    39,    48,    48,    50,
      48,    62,    73,   104,    39,    63,    96,    39,    96,    39,
      96,    37,    70,    48,    66,    39,    80,    39,    92,   100,
      48,    39,    39,    70,    48,    48,    62,    96,    39,    63,
      66,    66,    96,    96,    90,    39,    72,    39,    48,    48,
      39,    63,    39,    63,    66,    66,    39,    39,    66
};

#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
# define YYSIZE_T __SIZE_TYPE__
#endif
#if ! defined (YYSIZE_T) && defined (size_t)
# define YYSIZE_T size_t
#endif
#if ! defined (YYSIZE_T)
# if defined (__STDC__) || defined (__cplusplus)
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# endif
#endif
#if ! defined (YYSIZE_T)
# define YYSIZE_T unsigned int
#endif

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		(-2)
#define YYEOF		0

#define YYACCEPT	goto yyacceptlab
#define YYABORT		goto yyabortlab
#define YYERROR		goto yyerrlab1


/* Like YYERROR except do call yyerror.  This remains here temporarily
   to ease the transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */

#define YYFAIL		goto yyerrlab

#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)					\
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    {								\
      yychar = (Token);						\
      yylval = (Value);						\
      yytoken = YYTRANSLATE (yychar);				\
      YYPOPSTACK;						\
      goto yybackup;						\
    }								\
  else								\
    { 								\
      yyerror ("syntax error: cannot back up");\
      YYERROR;							\
    }								\
while (0)

#define YYTERROR	1
#define YYERRCODE	256

/* YYLLOC_DEFAULT -- Compute the default location (before the actions
   are run).  */

#ifndef YYLLOC_DEFAULT
# define YYLLOC_DEFAULT(Current, Rhs, N)         \
  Current.first_line   = Rhs[1].first_line;      \
  Current.first_column = Rhs[1].first_column;    \
  Current.last_line    = Rhs[N].last_line;       \
  Current.last_column  = Rhs[N].last_column;
#endif

/* YYLEX -- calling `yylex' with the right arguments.  */

#ifdef YYLEX_PARAM
# define YYLEX yylex (YYLEX_PARAM)
#else
# define YYLEX yylex ()
#endif

/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)			\
do {						\
  if (yydebug)					\
    YYFPRINTF Args;				\
} while (0)

# define YYDSYMPRINT(Args)			\
do {						\
  if (yydebug)					\
    yysymprint Args;				\
} while (0)

# define YYDSYMPRINTF(Title, Token, Value, Location)		\
do {								\
  if (yydebug)							\
    {								\
      YYFPRINTF (stderr, "%s ", Title);				\
      yysymprint (stderr, 					\
                  Token, Value);	\
      YYFPRINTF (stderr, "\n");					\
    }								\
} while (0)

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (cinluded).                                                   |
`------------------------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yy_stack_print (short *bottom, short *top)
#else
static void
yy_stack_print (bottom, top)
    short *bottom;
    short *top;
#endif
{
  YYFPRINTF (stderr, "Stack now");
  for (/* Nothing. */; bottom <= top; ++bottom)
    YYFPRINTF (stderr, " %d", *bottom);
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)				\
do {								\
  if (yydebug)							\
    yy_stack_print ((Bottom), (Top));				\
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yy_reduce_print (int yyrule)
#else
static void
yy_reduce_print (yyrule)
    int yyrule;
#endif
{
  int yyi;
  unsigned int yylineno = yyrline[yyrule];
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
             yyrule - 1, yylineno);
  /* Print the symbols being reduced, and their result.  */
  for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
    YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
  YYFPRINTF (stderr, "-> %s\n", yytname [yyr1[yyrule]]);
}

# define YY_REDUCE_PRINT(Rule)		\
do {					\
  if (yydebug)				\
    yy_reduce_print (Rule);		\
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YYDSYMPRINT(Args)
# define YYDSYMPRINTF(Title, Token, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef	YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#if YYMAXDEPTH == 0
# undef YYMAXDEPTH
#endif

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif



#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined (__GLIBC__) && defined (_STRING_H)
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
static YYSIZE_T
#   if defined (__STDC__) || defined (__cplusplus)
yystrlen (const char *yystr)
#   else
yystrlen (yystr)
     const char *yystr;
#   endif
{
  register const char *yys = yystr;

  while (*yys++ != '\0')
    continue;

  return yys - yystr - 1;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined (__GLIBC__) && defined (_STRING_H) && defined (_GNU_SOURCE)
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
#   if defined (__STDC__) || defined (__cplusplus)
yystpcpy (char *yydest, const char *yysrc)
#   else
yystpcpy (yydest, yysrc)
     char *yydest;
     const char *yysrc;
#   endif
{
  register char *yyd = yydest;
  register const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

#endif /* !YYERROR_VERBOSE */



#if YYDEBUG
/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yysymprint (FILE *yyoutput, int yytype, YYSTYPE *yyvaluep)
#else
static void
yysymprint (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvaluep;

  if (yytype < YYNTOKENS)
    {
      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
# ifdef YYPRINT
      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# endif
    }
  else
    YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);

  switch (yytype)
    {
      default:
        break;
    }
  YYFPRINTF (yyoutput, ")");
}

#endif /* ! YYDEBUG */
/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yydestruct (int yytype, YYSTYPE *yyvaluep)
#else
static void
yydestruct (yytype, yyvaluep)
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvaluep;

  switch (yytype)
    {

      default:
        break;
    }
}


/* Prevent warnings from -Wmissing-prototypes.  */

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int yyparse (void *YYPARSE_PARAM);
# else
int yyparse ();
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int yyparse (void);
#else
int yyparse ();
#endif
#endif /* ! YYPARSE_PARAM */



/* The lookahead symbol.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;

/* Number of syntax errors so far.  */
int yynerrs;



/*----------.
| yyparse.  |
`----------*/

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int yyparse (void *YYPARSE_PARAM)
# else
int yyparse (YYPARSE_PARAM)
  void *YYPARSE_PARAM;
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int
yyparse (void)
#else
int
yyparse ()

#endif
#endif
{
  
  register int yystate;
  register int yyn;
  int yyresult;
  /* Number of tokens to shift before error messages enabled.  */
  int yyerrstatus;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken = 0;

  /* Three stacks and their tools:
     `yyss': related to states,
     `yyvs': related to semantic values,
     `yyls': related to locations.

     Refer to the stacks thru separate pointers, to allow yyoverflow
     to reallocate them elsewhere.  */

  /* The state stack.  */
  short	yyssa[YYINITDEPTH];
  short *yyss = yyssa;
  register short *yyssp;

  /* The semantic value stack.  */
  YYSTYPE yyvsa[YYINITDEPTH];
  YYSTYPE *yyvs = yyvsa;
  register YYSTYPE *yyvsp;



#define YYPOPSTACK   (yyvsp--, yyssp--)

  YYSIZE_T yystacksize = YYINITDEPTH;

  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;


  /* When reducing, the number of symbols on the RHS of the reduced
     rule.  */
  int yylen;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY;		/* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */

  yyssp = yyss;
  yyvsp = yyvs;

  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed. so pushing a state here evens the stacks.
     */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
	/* Give user a chance to reallocate the stack. Use copies of
	   these so that the &'s don't force the real ones into
	   memory.  */
	YYSTYPE *yyvs1 = yyvs;
	short *yyss1 = yyss;


	/* Each stack pointer address is followed by the size of the
	   data in use in that stack, in bytes.  This used to be a
	   conditional around just the two extra args, but that might
	   be undefined if yyoverflow is a macro.  */
	yyoverflow ("parser stack overflow",
		    &yyss1, yysize * sizeof (*yyssp),
		    &yyvs1, yysize * sizeof (*yyvsp),

		    &yystacksize);

	yyss = yyss1;
	yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyoverflowlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
	goto yyoverflowlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
	yystacksize = YYMAXDEPTH;

      {
	short *yyss1 = yyss;
	union yyalloc *yyptr =
	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
	if (! yyptr)
	  goto yyoverflowlab;
	YYSTACK_RELOCATE (yyss);
	YYSTACK_RELOCATE (yyvs);

#  undef YYSTACK_RELOCATE
	if (yyss1 != yyssa)
	  YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;


      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
		  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
	YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

/* Do appropriate processing given the current state.  */
/* Read a lookahead token if we need one and don't already have one.  */
/* yyresume: */

  /* First try to decide what to do without reference to lookahead token.  */

  yyn = yypact[yystate];
  if (yyn == YYPACT_NINF)
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = YYLEX;
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yyn == 0 || yyn == YYTABLE_NINF)
	goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  /* Shift the lookahead token.  */
  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));

  /* Discard the token being shifted unless it is eof.  */
  if (yychar != YYEOF)
    yychar = YYEMPTY;

  *++yyvsp = yylval;


  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  yystate = yyn;
  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     `$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 3:
#line 98 "./parser.yy"
    { replot(); ;}
    break;

  case 4:
#line 99 "./parser.yy"
    { replot(); ;}
    break;

  case 5:
#line 100 "./parser.yy"
    {
    	warn ("Syntax error at the beginning of command."); 
	yyerrok; yyclearin; ;}
    break;

  case 6:
#line 103 "./parser.yy"
    { 
    	warn ("Syntax error near unknown token: `" + yyvsp[-2].s.str() + "'"); 
	yyerrok; yyclearin; ;}
    break;

  case 7:
#line 106 "./parser.yy"
    { warn("Parse error."); 
      yyerrok; yyclearin;;}
    break;

  case 8:
#line 110 "./parser.yy"
    { 
	set_class_p(yyvsp[-3].c)->setp (yyvsp[-2].s.str(), yyvsp[-1].s.str());
      ;}
    break;

  case 9:
#line 113 "./parser.yy"
    { set_class_p(yyvsp[-2].c)->getp (yyvsp[-1].s.str()); ;}
    break;

  case 10:
#line 114 "./parser.yy"
    { mesg (set_class_p(yyvsp[-1].c)->print_usage(yyvsp[-1].c)); ;}
    break;

  case 11:
#line 115 "./parser.yy"
    { AL->activate(yyvsp[-3].i, yyvsp[-1].i); ;}
    break;

  case 12:
#line 116 "./parser.yy"
    { AL->remove(yyvsp[-3].i, yyvsp[-1].i);;}
    break;

  case 13:
#line 117 "./parser.yy"
    { AL->append_core();;}
    break;

  case 14:
#line 118 "./parser.yy"
    { AL->append_data(yyvsp[-3].i); ;}
    break;

  case 15:
#line 119 "./parser.yy"
    { 
                             my_data->load_file(yyvsp[-1].s.str(), yyvsp[-3].c, ivec, ivec2, yyvsp[-2].i);
			     my_core->set_view (Rect()); ;}
    break;

  case 16:
#line 122 "./parser.yy"
    { my_data->change_range (yyvsp[-1].range.l, yyvsp[-1].range.r, yyvsp[-2].c == '+'); ;}
    break;

  case 17:
#line 123 "./parser.yy"
    { 
                                     my_data->change_range (-INF, +INF, false);
                                     my_data->change_range (yyvsp[-1].range.l, yyvsp[-1].range.r);
	                           ;}
    break;

  case 18:
#line 127 "./parser.yy"
    { 
		    mesg("Active data range: " + my_data->range_as_string()); ;}
    break;

  case 19:
#line 129 "./parser.yy"
    { my_data->auto_range (yyvsp[-2].f, yyvsp[-1].f); ;}
    break;

  case 20:
#line 130 "./parser.yy"
    { /*experimental auto-background*/
                 my_data->auto_background (yyvsp[-3].i, yyvsp[-2].f, false, yyvsp[-1].f, false); ;}
    break;

  case 21:
#line 132 "./parser.yy"
    { 
                  my_data->auto_background (yyvsp[-4].i, yyvsp[-3].f, true, yyvsp[-1].f, false); ;}
    break;

  case 22:
#line 134 "./parser.yy"
    { 
                  my_data->auto_background (yyvsp[-4].i, yyvsp[-3].f, false, yyvsp[-2].f, true); ;}
    break;

  case 23:
#line 136 "./parser.yy"
    {
                  my_data->auto_background (yyvsp[-5].i, yyvsp[-4].f, true, yyvsp[-2].f, true); ;}
    break;

  case 24:
#line 138 "./parser.yy"
    {my_data->add_background_point(yyvsp[-2].f, yyvsp[-1].f, bgc_bg);;}
    break;

  case 25:
#line 139 "./parser.yy"
    { my_data->rm_background_point(yyvsp[-1].f, bgc_bg); ;}
    break;

  case 26:
#line 140 "./parser.yy"
    { mesg (my_data->background_info(bgc_bg)); ;}
    break;

  case 27:
#line 141 "./parser.yy"
    { my_data->recompute_background(bgc_bg); ;}
    break;

  case 28:
#line 142 "./parser.yy"
    { my_data->clear_background(bgc_bg); ;}
    break;

  case 29:
#line 143 "./parser.yy"
    {my_data->add_background_point(yyvsp[-2].f, yyvsp[-1].f, bgc_cl);;}
    break;

  case 30:
#line 144 "./parser.yy"
    {my_data->rm_background_point(yyvsp[-1].f,bgc_cl);;}
    break;

  case 31:
#line 145 "./parser.yy"
    { mesg (my_data->background_info(bgc_cl)); ;}
    break;

  case 32:
#line 146 "./parser.yy"
    { my_data->recompute_background(bgc_cl); ;}
    break;

  case 33:
#line 147 "./parser.yy"
    { my_data->clear_background(bgc_cl); ;}
    break;

  case 34:
#line 148 "./parser.yy"
    { my_data->change_sigma(yyvsp[-2].c, yyvsp[-1].f); ;}
    break;

  case 35:
#line 149 "./parser.yy"
    { mesg (my_data->print_sigma()); ;}
    break;

  case 36:
#line 150 "./parser.yy"
    { mesg (my_data->getInfo()); ;}
    break;

  case 37:
#line 152 "./parser.yy"
    { my_data->export_to_file(yyvsp[-2].s.str(), yyvsp[-1].bol, yyvsp[-3].c);;}
    break;

  case 38:
#line 153 "./parser.yy"
    { my_fit->fit(true, yyvsp[-1].i); ;}
    break;

  case 39:
#line 154 "./parser.yy"
    { my_fit->fit(true, -1); ;}
    break;

  case 40:
#line 155 "./parser.yy"
    { my_fit->fit(false, yyvsp[-1].i); ;}
    break;

  case 41:
#line 156 "./parser.yy"
    { my_fit->fit(false, -1); ;}
    break;

  case 42:
#line 157 "./parser.yy"
    { mesg (fitMethodsContainer->print_current_method ()); ;}
    break;

  case 43:
#line 158 "./parser.yy"
    { fitMethodsContainer->change_method (yyvsp[-1].c); ;}
    break;

  case 44:
#line 159 "./parser.yy"
    { mesg (my_fit->getInfo(0)); ;}
    break;

  case 45:
#line 160 "./parser.yy"
    { mesg (my_fit->getInfo(1)); ;}
    break;

  case 46:
#line 161 "./parser.yy"
    { mesg (my_fit->getInfo(2)); ;}
    break;

  case 47:
#line 162 "./parser.yy"
    { my_sum->add_fzg (yyvsp[-2].fzg_type_type.fzg, yyvsp[-2].fzg_type_type.c, pgvec); ;}
    break;

  case 48:
#line 163 "./parser.yy"
    {/*nothing, @ is added inside a_num*/;}
    break;

  case 49:
#line 164 "./parser.yy"
    { AL->pars()->change_a (yyvsp[-3].i, yyvsp[-2].f, yyvsp[-1].c); ;}
    break;

  case 50:
#line 165 "./parser.yy"
    { AL->pars()->change_a(yyvsp[-4].i, yyvsp[-3].f, yyvsp[-2].c);
                                  AL->pars()->change_domain (yyvsp[-4].i, Domain(yyvsp[-1].pre_domain)); ;}
    break;

  case 51:
#line 167 "./parser.yy"
    { my_sum->change_f (yyvsp[-2].i, yyvsp[-1].c); ;}
    break;

  case 52:
#line 169 "./parser.yy"
    { my_sum->change_in_f (yyvsp[-5].i, ivec, pgvec); ;}
    break;

  case 53:
#line 170 "./parser.yy"
    { mesg (AL->pars()->frozen_info ()); ;}
    break;

  case 54:
#line 171 "./parser.yy"
    { AL->pars()->freeze(yyvsp[-1].i, true); ;}
    break;

  case 55:
#line 172 "./parser.yy"
    { AL->pars()->freeze(yyvsp[-1].i, false); ;}
    break;

  case 56:
#line 173 "./parser.yy"
    { mesg (AL->pars()->print_history()); ;}
    break;

  case 57:
#line 174 "./parser.yy"
    { AL->pars()->move_in_history (yyvsp[-1].i, true); ;}
    break;

  case 58:
#line 175 "./parser.yy"
    { AL->pars()->move_in_history (yyvsp[-1].i, false); ;}
    break;

  case 59:
#line 176 "./parser.yy"
    { AL->pars()->toggle_history_item_saved(yyvsp[-1].i); ;}
    break;

  case 60:
#line 177 "./parser.yy"
    { mesg (AL->pars()->history_diff (ivec)); ;}
    break;

  case 61:
#line 178 "./parser.yy"
    { mesg (AL->pars()->info_a (yyvsp[-1].i)); ;}
    break;

  case 62:
#line 179 "./parser.yy"
    { mesg (my_sum->info_fzg (yyvsp[-1].fzg_num_type.fzg, yyvsp[-1].fzg_num_type.i, true)); ;}
    break;

  case 63:
#line 180 "./parser.yy"
    { mesg (V_fzg::print_type_info (gType, 0)); ;}
    break;

  case 64:
#line 181 "./parser.yy"
    { mesg (V_fzg::print_type_info (fType, 0)); ;}
    break;

  case 65:
#line 182 "./parser.yy"
    { mesg (V_fzg::print_type_info (zType, 0)); ;}
    break;

  case 66:
#line 183 "./parser.yy"
    { mesg (V_fzg::print_type_info (yyvsp[-1].fzg_type_type.fzg, yyvsp[-1].fzg_type_type.c));;}
    break;

  case 67:
#line 184 "./parser.yy"
    { mesg (my_sum->general_info()); ;}
    break;

  case 68:
#line 185 "./parser.yy"
    { my_sum->guess_f(yyvsp[-1].i); ;}
    break;

  case 69:
#line 186 "./parser.yy"
    { AL->pars()->rm_a (yyvsp[-1].i); ;}
    break;

  case 70:
#line 187 "./parser.yy"
    { my_sum->rm_fzg (yyvsp[-1].fzg_num_type.fzg, yyvsp[-1].fzg_num_type.i); ;}
    break;

  case 71:
#line 188 "./parser.yy"
    { my_sum->rm_all(); ;}
    break;

  case 72:
#line 189 "./parser.yy"
    { mesg (my_sum->print_sum_value (yyvsp[-2].f, yyvsp[-1].bol)); ;}
    break;

  case 73:
#line 191 "./parser.yy"
    { mesg (my_sum->print_fzg_value(yyvsp[-3].fzg_num_type.fzg, yyvsp[-3].fzg_num_type.i, yyvsp[-2].f, yyvsp[-1].bol)); ;}
    break;

  case 74:
#line 192 "./parser.yy"
    {mesg (my_sum->print_fzg_value (gType, yyvsp[-1].i));;}
    break;

  case 75:
#line 193 "./parser.yy"
    { mesg (AL->pars()->info_a (yyvsp[-1].i)); ;}
    break;

  case 76:
#line 194 "./parser.yy"
    { 
                             my_sum->export_to_file (yyvsp[-2].s.str(), yyvsp[-1].bol, yyvsp[-3].c, ivec); ;}
    break;

  case 77:
#line 196 "./parser.yy"
    { 
                            mesg (my_manipul->print_simple_estimate (yyvsp[-2].f, yyvsp[-1].f)); ;}
    break;

  case 78:
#line 198 "./parser.yy"
    {mesg (my_manipul->print_global_peakfind());;}
    break;

  case 79:
#line 199 "./parser.yy"
    { getUI()->drawPlot(1, true);;}
    break;

  case 80:
#line 200 "./parser.yy"
    { my_core->set_view (Rect(yyvsp[-1].range.l, yyvsp[-1].range.r), true); ;}
    break;

  case 81:
#line 201 "./parser.yy"
    { 
                            my_core->set_view (Rect(yyvsp[-2].range.l, yyvsp[-2].range.r, yyvsp[-1].range.l, yyvsp[-1].range.r)); ;}
    break;

  case 82:
#line 203 "./parser.yy"
    { my_core->set_view_v (yyvsp[-1].range.l, yyvsp[-1].range.r); ;}
    break;

  case 83:
#line 204 "./parser.yy"
    { my_core->set_view_h (yyvsp[-2].range.l, yyvsp[-2].range.r); ;}
    break;

  case 84:
#line 205 "./parser.yy"
    { mesg (my_core->view_info()); ;}
    break;

  case 85:
#line 206 "./parser.yy"
    { mesg (my_core->view_info()); ;}
    break;

  case 86:
#line 207 "./parser.yy"
    { my_core->set_plus_background(yyvsp[-1].c == '+'); ;}
    break;

  case 87:
#line 208 "./parser.yy"
    { getUI()->startLog(yyvsp[-2].c, yyvsp[-1].s.str()); ;}
    break;

  case 88:
#line 209 "./parser.yy"
    { getUI()->stopLog(); ;}
    break;

  case 89:
#line 210 "./parser.yy"
    { mesg (getUI()->getLogInfo()); ;}
    break;

  case 90:
#line 211 "./parser.yy"
    { getUI()->execScript(yyvsp[-2].s.str(), ivec);;}
    break;

  case 91:
#line 212 "./parser.yy"
    { AL->reset_all(); 
                                       getUI()->execScript(yyvsp[-2].s.str(), ivec);;}
    break;

  case 92:
#line 214 "./parser.yy"
    { AL->reset_all(); ;}
    break;

  case 93:
#line 215 "./parser.yy"
    { getUI()->wait (yyvsp[-1].f); ;}
    break;

  case 94:
#line 216 "./parser.yy"
    { AL->dump_all_as_script (yyvsp[-1].s.str()); ;}
    break;

  case 95:
#line 217 "./parser.yy"
    { YYABORT;;}
    break;

  case 96:
#line 219 "./parser.yy"
    { my_crystal->xrays.add (pgvec); ;}
    break;

  case 97:
#line 220 "./parser.yy"
    { my_crystal->xrays.clear(); ;}
    break;

  case 98:
#line 221 "./parser.yy"
    { mesg (my_crystal->wavelength_info()); ;}
    break;

  case 99:
#line 222 "./parser.yy"
    { my_crystal->add_phase (yyvsp[-2].c, pgvec); ;}
    break;

  case 100:
#line 223 "./parser.yy"
    { my_crystal->add_plane (yyvsp[-1].ph_n_pl.ph, yyvsp[-1].ph_n_pl.hkl); ;}
    break;

  case 101:
#line 224 "./parser.yy"
    { 
                          my_crystal->add_plane_as_f (yyvsp[-2].ph_n_pl.ph, yyvsp[-2].ph_n_pl.hkl, ivec); ;}
    break;

  case 102:
#line 226 "./parser.yy"
    { mesg (my_crystal->phase_type_info()); ;}
    break;

  case 103:
#line 227 "./parser.yy"
    { mesg (my_crystal->phase_type_info()); ;}
    break;

  case 104:
#line 228 "./parser.yy"
    { mesg (my_crystal->phase_info (yyvsp[-1].i) + "\n"
    				     + my_crystal->list_planes_in_phase (yyvsp[-1].i)); ;}
    break;

  case 105:
#line 230 "./parser.yy"
    { mesg (my_crystal->plane_info (yyvsp[-1].ph_n_pl.ph, yyvsp[-1].ph_n_pl.hkl)); ;}
    break;

  case 106:
#line 231 "./parser.yy"
    { mesg (my_crystal->wavelength_info() + "\n"
                                            + my_crystal->phase_info (-1)); ;}
    break;

  case 107:
#line 233 "./parser.yy"
    { my_crystal->rm_phase (yyvsp[-1].i); ;}
    break;

  case 108:
#line 234 "./parser.yy"
    { my_crystal->rm_plane (yyvsp[-1].ph_n_pl.ph, yyvsp[-1].ph_n_pl.hkl); ;}
    break;

  case 109:
#line 235 "./parser.yy"
    { 
                       mesg (my_crystal->print_estimate (yyvsp[-2].ph_n_pl.ph, yyvsp[-2].ph_n_pl.hkl, yyvsp[-1].f)); ;}
    break;

  case 110:
#line 240 "./parser.yy"
    { yyval.i = yyvsp[0].i; ;}
    break;

  case 111:
#line 241 "./parser.yy"
    { yyval.i = AL->pars()->add_a(yyvsp[0].f, Domain()) .a(); ;}
    break;

  case 112:
#line 242 "./parser.yy"
    { yyval.i = AL->pars()->add_a(yyvsp[-1].f, Domain(yyvsp[0].pre_domain)) .a(); ;}
    break;

  case 113:
#line 245 "./parser.yy"
    { yyval.pre_domain.set = yyval.pre_domain.ctr_set = false; ;}
    break;

  case 114:
#line 246 "./parser.yy"
    { yyval.pre_domain.set = true; yyval.pre_domain.ctr_set = true; 
                              yyval.pre_domain.ctr = (yyvsp[-3].f + yyvsp[-1].f) / 2; yyval.pre_domain.sigma = (yyvsp[-1].f - yyvsp[-3].f) / 2;;}
    break;

  case 115:
#line 248 "./parser.yy"
    { yyval.pre_domain.set=true; yyval.pre_domain.ctr_set=false; yyval.pre_domain.sigma = yyvsp[-1].f; ;}
    break;

  case 116:
#line 249 "./parser.yy"
    { yyval.pre_domain.set = true; yyval.pre_domain.ctr_set = true; 
				     yyval.pre_domain.ctr = yyvsp[-3].f; yyval.pre_domain.sigma = yyvsp[-1].f; ;}
    break;

  case 117:
#line 251 "./parser.yy"
    { yyval.pre_domain.set = true; yyval.pre_domain.ctr_set = true; 
					 yyval.pre_domain.ctr = yyvsp[-4].f; yyval.pre_domain.sigma = yyvsp[-2].f * yyvsp[-4].f / 100;;}
    break;

  case 118:
#line 255 "./parser.yy"
    { yyval.c = '='; ;}
    break;

  case 119:
#line 256 "./parser.yy"
    { yyval.c = '%'; ;}
    break;

  case 120:
#line 259 "./parser.yy"
    { yyval.range.l = -INF; yyval.range.r = +INF; ;}
    break;

  case 121:
#line 260 "./parser.yy"
    { yyval.range.l = yyvsp[-1].f; yyval.range.r = +INF; ;}
    break;

  case 122:
#line 261 "./parser.yy"
    { yyval.range.l = -INF; yyval.range.r = yyvsp[0].f; ;}
    break;

  case 123:
#line 264 "./parser.yy"
    { yyval.range.l = -INF; yyval.range.r = +INF; ;}
    break;

  case 124:
#line 265 "./parser.yy"
    { yyval.range = yyvsp[-1].range ;}
    break;

  case 125:
#line 266 "./parser.yy"
    { yyval.range.l = yyvsp[-2].f; yyval.range.r = yyvsp[0].f; ;}
    break;

  case 126:
#line 267 "./parser.yy"
    { yyval.range.l = yyvsp[-3].f; yyval.range.r = yyvsp[-1].f; ;}
    break;

  case 127:
#line 270 "./parser.yy"
    { yyval.range = yyvsp[0].range; ;}
    break;

  case 128:
#line 271 "./parser.yy"
    { yyval.range = yyvsp[0].range; ;}
    break;

  case 129:
#line 274 "./parser.yy"
    {yyval.ph_n_pl.ph = yyvsp[-1].i; yyval.ph_n_pl.hkl=yyvsp[0].pl; ;}
    break;

  case 130:
#line 275 "./parser.yy"
    {yyval.ph_n_pl.ph = 0;  yyval.ph_n_pl.hkl=yyvsp[0].pl; ;}
    break;

  case 131:
#line 278 "./parser.yy"
    { if (yyvsp[-1].i < 1 /*1==001*/ || yyvsp[-1].i > 999) { 
                          yyval.pl.h = yyval.pl.k =yyval.pl.l = 0;
                          warn("Please separate Miller's indices with spaces.");
			 }
                           else yyval.pl.h = yyvsp[-1].i/100, yyval.pl.k=yyvsp[-1].i%100/10, yyval.pl.l=yyvsp[-1].i%10;   
		       ;}
    break;

  case 132:
#line 284 "./parser.yy"
    { yyval.pl.h = yyvsp[-3].i; yyval.pl.k = yyvsp[-2].i; yyval.pl.l = yyvsp[-1].i; ;}
    break;

  case 133:
#line 287 "./parser.yy"
    { yyval.pre_pag.c = 'a'; yyval.pre_pag.n = yyvsp[0].i; ;}
    break;

  case 134:
#line 288 "./parser.yy"
    { yyval.pre_pag.c = 'g'; yyval.pre_pag.n = yyvsp[0].i; ;}
    break;

  case 135:
#line 289 "./parser.yy"
    { yyval.pre_pag.c = 'p'; yyval.pre_pag.p = yyvsp[0].f; ;}
    break;

  case 136:
#line 292 "./parser.yy"
    { yyval.fzg_type_type.fzg = fType; yyval.fzg_type_type.c = yyvsp[0].c; ;}
    break;

  case 137:
#line 293 "./parser.yy"
    { yyval.fzg_type_type.fzg = zType; yyval.fzg_type_type.c = yyvsp[0].c; ;}
    break;

  case 138:
#line 294 "./parser.yy"
    { yyval.fzg_type_type.fzg = gType; yyval.fzg_type_type.c = yyvsp[0].c; ;}
    break;

  case 139:
#line 297 "./parser.yy"
    { yyval.fzg_num_type.fzg = fType; yyval.fzg_num_type.i = yyvsp[0].i; ;}
    break;

  case 140:
#line 298 "./parser.yy"
    { yyval.fzg_num_type.fzg = zType; yyval.fzg_num_type.i = yyvsp[0].i; ;}
    break;

  case 141:
#line 299 "./parser.yy"
    { yyval.fzg_num_type.fzg = gType; yyval.fzg_num_type.i = yyvsp[0].i; ;}
    break;

  case 142:
#line 302 "./parser.yy"
    { pgvec = vector1 (Pag(yyvsp[0].pre_pag)); ;}
    break;

  case 143:
#line 303 "./parser.yy"
    { pgvec.push_back (Pag(yyvsp[0].pre_pag)); ;}
    break;

  case 144:
#line 306 "./parser.yy"
    { ivec = vector1(yyvsp[0].i); ;}
    break;

  case 145:
#line 307 "./parser.yy"
    { ivec.push_back(yyvsp[0].i); ;}
    break;

  case 147:
#line 311 "./parser.yy"
    { yyval.i = yyvsp[0].i; ;}
    break;

  case 148:
#line 314 "./parser.yy"
    { yyval.i = 0; ;}
    break;

  case 149:
#line 315 "./parser.yy"
    { yyval.i = yyvsp[0].i; ;}
    break;

  case 150:
#line 318 "./parser.yy"
    { yyval.i = -1; ;}
    break;

  case 151:
#line 319 "./parser.yy"
    { yyval.i = yyvsp[0].i; ;}
    break;

  case 152:
#line 322 "./parser.yy"
    { ivec = vector1(yyvsp[0].i); ;}
    break;

  case 153:
#line 323 "./parser.yy"
    { ivec.push_back(yyvsp[0].i); ;}
    break;

  case 155:
#line 327 "./parser.yy"
    { yyval.f = (double) yyvsp[0].i; ;}
    break;

  case 156:
#line 330 "./parser.yy"
    { yyval.f = 0; ;}
    break;

  case 157:
#line 331 "./parser.yy"
    { yyval.f = yyvsp[0].f ;}
    break;

  case 158:
#line 334 "./parser.yy"
    { yyval.c = 0; ;}
    break;

  case 159:
#line 335 "./parser.yy"
    { yyval.c = yyvsp[0].c; ;}
    break;

  case 160:
#line 338 "./parser.yy"
    { yyval.bol = false; ;}
    break;

  case 161:
#line 339 "./parser.yy"
    { yyval.bol = true;  ;}
    break;

  case 162:
#line 341 "./parser.yy"
    { yyval.bol = false; ;}
    break;

  case 163:
#line 342 "./parser.yy"
    { yyval.bol = true;  ;}
    break;

  case 164:
#line 345 "./parser.yy"
    { ivec.clear(); ;}
    break;

  case 165:
#line 346 "./parser.yy"
    { ivec = vector1(yyvsp[0].i); ;}
    break;

  case 166:
#line 347 "./parser.yy"
    { ivec = my_crystal->get_funcs_in_phase(yyvsp[0].i); ;}
    break;

  case 167:
#line 348 "./parser.yy"
    { ivec = my_crystal->get_funcs_in_plane (yyvsp[0].ph_n_pl.ph, yyvsp[0].ph_n_pl.hkl); ;}
    break;

  case 168:
#line 349 "./parser.yy"
    { ivec.push_back(yyvsp[0].i); ;}
    break;

  case 169:
#line 350 "./parser.yy"
    { vector<int>k=my_crystal->get_funcs_in_phase(yyvsp[0].i);
				ivec.insert (ivec.end(), k.begin(), k.end()); ;}
    break;

  case 170:
#line 352 "./parser.yy"
    { 
                 vector<int> k = my_crystal->get_funcs_in_plane (yyvsp[0].ph_n_pl.ph, yyvsp[0].ph_n_pl.hkl);
                                ivec.insert (ivec.end(), k.begin(), k.end()); ;}
    break;

  case 171:
#line 357 "./parser.yy"
    { ivec.clear(); ;}
    break;

  case 172:
#line 358 "./parser.yy"
    { ivec = vector2 (yyvsp[-2].i, yyvsp[0].i); ;}
    break;

  case 173:
#line 359 "./parser.yy"
    { ivec = vector3 (yyvsp[-4].i, yyvsp[-2].i, yyvsp[0].i); ;}
    break;

  case 174:
#line 362 "./parser.yy"
    { ivec2.clear(); ;}
    break;

  case 175:
#line 363 "./parser.yy"
    { ivec2 = vector2(yyvsp[-1].i, yyvsp[0].i); ;}
    break;

  case 176:
#line 364 "./parser.yy"
    { ivec2 = vector3 (yyvsp[-2].i, yyvsp[-1].i, yyvsp[0].i); ;}
    break;

  case 177:
#line 365 "./parser.yy"
    { ivec2 = vector3(yyvsp[-1].i, yyvsp[-1].i, yyvsp[0].i); ;}
    break;

  case 178:
#line 368 "./parser.yy"
    { yyval.i = 0; ;}
    break;

  case 179:
#line 369 "./parser.yy"
    { yyval.i = -yyvsp[0].i; ;}
    break;

  case 180:
#line 370 "./parser.yy"
    { yyval.i = yyvsp[0].i; ;}
    break;

  case 181:
#line 373 "./parser.yy"
    { yyval.i = yyvsp[0].i; ;}
    break;

  case 182:
#line 376 "./parser.yy"
    { ivec.clear(); ;}
    break;

  case 183:
#line 377 "./parser.yy"
    { ivec.push_back(yyvsp[-1].i); ivec.push_back(yyvsp[0].i); ;}
    break;

  case 184:
#line 378 "./parser.yy"
    { ivec.push_back(yyvsp[0].i); ivec.push_back(yyvsp[0].i); ;}
    break;

  case 185:
#line 381 "./parser.yy"
    { yyval.c = '+'; ;}
    break;

  case 186:
#line 382 "./parser.yy"
    { yyval.c = '-'; ;}
    break;

  case 187:
#line 385 "./parser.yy"
    { ivec = vector1 (yyvsp[0].i); ;}
    break;

  case 188:
#line 386 "./parser.yy"
    { ivec.push_back (yyvsp[0].i); ;}
    break;

  case 189:
#line 389 "./parser.yy"
    { /*nothing*/;         ;}
    break;

  case 190:
#line 390 "./parser.yy"
    { ivec.push_back (yyvsp[0].i); ;}
    break;

  case 191:
#line 391 "./parser.yy"
    { ivec.clear();        ;}
    break;


    }

/* Line 999 of yacc.c.  */
#line 2494 "parser.tab.cc"

  yyvsp -= yylen;
  yyssp -= yylen;


  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;


  /* Now `shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*------------------------------------.
| yyerrlab -- here on detecting error |
`------------------------------------*/
yyerrlab:
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if YYERROR_VERBOSE
      yyn = yypact[yystate];

      if (YYPACT_NINF < yyn && yyn < YYLAST)
	{
	  YYSIZE_T yysize = 0;
	  int yytype = YYTRANSLATE (yychar);
	  char *yymsg;
	  int yyx, yycount;

	  yycount = 0;
	  /* Start YYX at -YYN if negative to avoid negative indexes in
	     YYCHECK.  */
	  for (yyx = yyn < 0 ? -yyn : 0;
	       yyx < (int) (sizeof (yytname) / sizeof (char *)); yyx++)
	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
	      yysize += yystrlen (yytname[yyx]) + 15, yycount++;
	  yysize += yystrlen ("syntax error, unexpected ") + 1;
	  yysize += yystrlen (yytname[yytype]);
	  yymsg = (char *) YYSTACK_ALLOC (yysize);
	  if (yymsg != 0)
	    {
	      char *yyp = yystpcpy (yymsg, "syntax error, unexpected ");
	      yyp = yystpcpy (yyp, yytname[yytype]);

	      if (yycount < 5)
		{
		  yycount = 0;
		  for (yyx = yyn < 0 ? -yyn : 0;
		       yyx < (int) (sizeof (yytname) / sizeof (char *));
		       yyx++)
		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
		      {
			const char *yyq = ! yycount ? ", expecting " : " or ";
			yyp = yystpcpy (yyp, yyq);
			yyp = yystpcpy (yyp, yytname[yyx]);
			yycount++;
		      }
		}
	      yyerror (yymsg);
	      YYSTACK_FREE (yymsg);
	    }
	  else
	    yyerror ("syntax error; also virtual memory exhausted");
	}
      else
#endif /* YYERROR_VERBOSE */
	yyerror ("syntax error");
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
	 error, discard it.  */

      /* Return failure if at end of input.  */
      if (yychar == YYEOF)
        {
	  /* Pop the error token.  */
          YYPOPSTACK;
	  /* Pop the rest of the stack.  */
	  while (yyss < yyssp)
	    {
	      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
	      yydestruct (yystos[*yyssp], yyvsp);
	      YYPOPSTACK;
	    }
	  YYABORT;
        }

      YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
      yydestruct (yytoken, &yylval);
      yychar = YYEMPTY;

    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*----------------------------------------------------.
| yyerrlab1 -- error raised explicitly by an action.  |
`----------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;	/* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (yyn != YYPACT_NINF)
	{
	  yyn += YYTERROR;
	  if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
	    {
	      yyn = yytable[yyn];
	      if (0 < yyn)
		break;
	    }
	}

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
	YYABORT;

      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
      yydestruct (yystos[yystate], yyvsp);
      yyvsp--;
      yystate = *--yyssp;

      YY_STACK_PRINT (yyss, yyssp);
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  YYDPRINTF ((stderr, "Shifting error token, "));

  *++yyvsp = yylval;


  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#ifndef yyoverflow
/*----------------------------------------------.
| yyoverflowlab -- parser overflow comes here.  |
`----------------------------------------------*/
yyoverflowlab:
  yyerror ("parser stack overflow");
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
  return yyresult;
}


#line 97 "./parser.yy"


int iperror (char * /*s*/) { return 0; }

void start_of_string_parsing(const char *s);
void end_of_string_parsing();

bool parser (std::string cmd)
{
    cmd = " " + cmd + "\n";
    start_of_string_parsing (cmd.c_str());
    int result = ipparse();
    end_of_string_parsing();
    return result == 0 ? true : false;
}


